@@ -19,12 +19,13 @@ use Term::ANSIColor;
 use Log::Fast;
 use Time::HiRes qw(time);
 use File::Basename;
+use Data::Dumper;
 
 BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 1.07;
+    our $VERSION = 1.09;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -531,7 +532,7 @@ sub debug {
     } elsif (ref($msgs) eq 'ARRAY') {
         @messages = @{$msgs};
     } else {
-        push(@messages,'** Not a scalar or array reference!  Debug::Easy no longer supports generating Data::Dumper output.  You must do this yourself, and then sent the output to Debug::Easy **');
+        push(@messages,Dumper($msgs));
     } ## end else [ if (ref($msgs) eq 'SCALAR'...)]
     my ($sname, $cline, $nested, $subroutine, $thisBench, $thisBench2, $sline, $short) = ('', '', '', '', '', '', '', '');
 
@@ -568,7 +569,7 @@ sub debug {
         } else {
             my @array = caller(1);
             $cline = $array[2];
-            if ($cline eq '') {
+            if (!defined($cline) || $cline eq '') {
                 @array = caller(0);
                 $cline = $array[2];
             }
@@ -598,7 +599,7 @@ sub debug {
     my $first = TRUE;    # Set the first line flag.
     foreach my $msg (@messages) {    # Loop through each line of output and format accordingly.
         if (ref($msg) ne '') {
-            $msg = '** Not a scalar or array reference!  Debug::Easy no longer supports generating Data::Dumper output.  You must do this yourself, and then sent the output to Debug::Easy **';
+            $msg = Dumper($msg);
         } ## end if (ref($msg) ne '')
         if ($msg =~ /\n/s) {         # If the line contains newlines, then it too must be split into multiple lines.
             my @message = split(/\n/, $msg);
@@ -865,7 +866,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 1.07    (September 04, 2015)
+Version 1.08    (September 11, 2015)
 
 =head1 BUGS
 
